/** \file Modulo DISCO
 *  \brief Funções de manipulação de dados em disco
 *
 */

/* Operações na agenda */
#define LEITURA 1  /**<Indica operação de leitura */
#define ESCRITA 2  /**<Indica operação de escrita */

/** tipo especial para manipulação de arquivo */
#include <gdbm.h>
typedef GDBM_FILE FP;

/** \fn FP abrir(char *arquivo, char *modo)
    \brief Abre arquivo da agenda em disco
    \param arquivo nome do arquivo com a agenda.
    \param modo modo de uso do arquivo.
*/
FP abrir(char *, char *);

/** \fn FP abrir(FP fp)
    \brief Fecha arquivo da agenda em disco 
    \param fp descritor do arquivo
*/
void fechar(FP);

/** \fn int gravaAgenda(ENDERECO *agenda, int nelem, FP fp)
    \brief Grava \a nelem registros do vetor \a agenda no arquivo com descritor \a fp
    \param agenda endereço inicial do vetor contendo os registros da agenda
    \param nelem número de registros da agenda a serem gravados
    \param fp descritor do arquivo
    \return 1 se gravou com sucesso ou 0 caso contrário.
 */
int gravaAgenda (ENDERECO *, int, FP);

/** \fn ENDERECO *leAgenda(int nelem, FP fp)
    \brief Lê conteúdo da agenda para memória
    \param nelem número de registros da agenda a serem gravados
    \param fp descritor do arquivo
    \return endereço do vetor onde foram armazenados os registros da agenda. Este vetor é
            alocado via calloc(). Se retorna NULL, houve erro de alocaçao e a leitura não foi feita.
 */
ENDERECO *leAgenda (int, FP);

